@@ -9,6 +9,6 @@ import applescript.tell
 from ._run import _run
 
 
-def run(applescript, background=False, javascript=True):
+def run(applescript, background=False, javascript=False):
     """run applescript file/string"""
     return _run(applescript, background, javascript)
